/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.saml.saml1.core.impl;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.opensaml.core.xml.XMLObject;
import org.opensaml.saml.common.AbstractSAMLObject;
import org.opensaml.saml.saml1.core.NameIdentifier;
import org.opensaml.saml.saml1.core.Subject;
import org.opensaml.saml.saml1.core.SubjectConfirmation;

/**
 * Complete implementation of {@link org.opensaml.saml.saml1.core.Subject}.
 */
public class SubjectImpl extends AbstractSAMLObject implements Subject {

    /** Contains the NameIdentifier inside the Subject. */
    private NameIdentifier nameIdentifier;

    /** Contains the SubjectConfirmation inside the Subject. */
    private SubjectConfirmation subjectConfirmation;

    /**
     * Constructor.
     * 
     * @param namespaceURI the namespace the element is in
     * @param elementLocalName the local name of the XML element this Object represents
     * @param namespacePrefix the prefix for the given namespace
     */
    protected SubjectImpl(final String namespaceURI, final String elementLocalName, final String namespacePrefix) {
        super(namespaceURI, elementLocalName, namespacePrefix);
    }

    /** {@inheritDoc} */
    public NameIdentifier getNameIdentifier() {
        return nameIdentifier;
    }

    /** {@inheritDoc} */
    public void setNameIdentifier(final NameIdentifier name) {
        nameIdentifier = prepareForAssignment(nameIdentifier, name);
    }

    /** {@inheritDoc} */
    public SubjectConfirmation getSubjectConfirmation() {
        return subjectConfirmation;
    }

    /** {@inheritDoc} */
    public void setSubjectConfirmation(final SubjectConfirmation conf) {
        subjectConfirmation = prepareForAssignment(subjectConfirmation, conf);
    }

    /** {@inheritDoc} */
    public List<XMLObject> getOrderedChildren() {

        final List<XMLObject> list = new ArrayList<>(2);

        if (nameIdentifier != null) {
            list.add(nameIdentifier);
        }

        if (subjectConfirmation != null) {
            list.add(subjectConfirmation);
        }
        if (list.size() == 0) {
            return null;
        }

        return Collections.unmodifiableList(list);
    }
}